@@ -8,32 +8,49 @@ try:
     stream = open('%s/config.yaml' % os.getcwd(), 'r')
     config = yaml.load(stream)
     stream.close()
+    if config is None:
+        config = {}
 except IOError:
     config = {}
 
 # set up the defaults
+# the name of the title block 
+try:
+    TITLE_BLOCK = config['TITLE_BLOCK']
+except (TypeError, KeyError):
+    TITLE_BLOCK = 'title'
+try:
+    NAV_IGNORE_DIRS = config['NAV_IGNORE_DIRS']
+except (TypeError, KeyError):
+    NAV_IGNORE_DIRS = ['img', 'css', 'js']
 # the name of the build dir
 try:
     BUILD_DIR = config['BUILD_DIR']
-except KeyError:
+except (TypeError, KeyError):
     BUILD_DIR = '_build'
 # exclude these directories and files
 try:
     EXCLUDED = config['EXCLUDED']
-except KeyError:
+except (TypeError, KeyError):
     EXCLUDED = (
         '_build',
         '.sass-cache',
-        'layout.html',
         '.DS_Store',
-        'config.yaml',
         'conf.py',
         'conf.pyc',
     )
-# which extentions to renderr?
+# utility nodes
 try:
-    EXTENSIONS = config['EXTENSIONS']
-except KeyError:
+    UTILITY_NODES = config['UTILITY_NODES']
+except (TypeError, KeyError):
+    UTILITY_NODES = (
+        'layout.html',
+        'config.yaml',
+    )
+# which extentions to render?
+try:
+    EXTENTIONS = config['EXTENTIONS']
+except (TypeError, KeyError):
     EXTENTIONS = (
         '.html',
         '.css',
@@ -41,12 +58,12 @@ except KeyError:
 # the blocks to parse for code and markdown
 try:
     CONTENT_BLOCK = config['CONTENT_BLOCK']
-except KeyError:
+except (TypeError, KeyError):
     CONTENT_BLOCK = 'content'
 # exclude these files
 try:
     FILTERS = config['FILTERS']
-except KeyError:
+except (TypeError, KeyError):
     FILTERS = (
        'pygmentize',
        'markdown',
@@ -54,6 +71,6 @@ except KeyError:
 # the root for urls and paths - forward slash essential
 try:
     ROOT = config['ROOT']
-except KeyError:
+except (TypeError, KeyError):
     ROOT = '/'
 JINJA_ENV = Environment( loader=FileSystemLoader('.'))
